TzDatetimeAndroid class

Inheritance
  • Object
  • PlatformInterface
  • TzDatetimeAndroid

Constructors

TzDatetimeAndroid()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAvailableTimezones() List<String>
Gets all available zones from the platform.
getOffset(DateTime date, String zoneId) Duration
Gets the current offset from the given date and zone identifier.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith() → void